
/** 节流函数 **/
export function dj_throttle (callback,delay = 50) {
  // 利用闭包保存时间
  let prev = Date.now()
  return function () {
    let context = this
    let arg = arguments
    let now = Date.now()
    if (now - prev >= delay) {
      callback.apply(context, arg)
      prev = Date.now()
    }
  }
}

/** 防抖函数 **/
export function dj_debounce (callback, delay = 50) {
  // 利用闭包保存定时器
  let timer = null
  return function () {
    let context = this
    let arg = arguments
    // 在规定时间内再次触发会先清除定时器后再重设定时器
    clearTimeout(timer)
    timer = setTimeout(function () {
      callback.apply(context, arg)
      clearTimeout(timer)
      timer = null
    }, delay)

  }
}

export function dj_addResizeObserve(callback, delay){
  window.addEventListener("resize",dj_debounce(callback,delay))
}
export function dj_removeResizeObserve(callback, delay){
  window.removeEventListener('resize',dj_debounce(callback,delay))
}
